@@ -1,4 +1,4 @@
-use anyhow::{bail, Context, Result};
+use anyhow::Result;
 use chrono::{Local, TimeZone, Utc};
 use flate2::write::GzEncoder;
 use flate2::Compression;
@@ -34,20 +34,6 @@ impl FileManipulator {
     }
 
     pub fn read_to_zip(&self) -> Result<()> {
-        for input_dir in &self.input_dirs {
-            if !input_dir.is_dir() {
-                bail!("The input path `{}` is not a directory", input_dir.display());
-            }
-        }
-        if !self.output_dir.is_dir() {
-            bail!("Output path is not a directory");
-        }
-        self.zip_dir()
-            .with_context(|| "Failed to compress directory into tarball")?;
-        Ok(())
-    }
-
-    fn zip_dir(&self) -> Result<()> {
         let mut output_path = self.output_dir.clone();
         output_path.push(format!(
             "Backup-{}.tar.gz",
